===============
Analysis Tools
===============

Differential Gene Expression
----------------------------
.. currentmodule:: glue_genes.glue_single_cell.qt.diff_gene_exp

.. automodule:: glue_genes.glue_single_cell.qt.diff_gene_exp


.. autosummary::
   :toctree: api/
   
   get_gene_diff_exp
   DifferentialGeneExpressionListener

Gene Subset Summary
----------------------------

.. currentmodule:: glue_genes.glue_single_cell.qt.summarize_gene_subset

.. automodule:: glue_genes.glue_single_cell.qt.summarize_gene_subset

.. autosummary::
   :toctree: api/

   do_calculation_over_gene_subset
   GeneSummaryListener

Enrich Gene Subset
----------------------------
.. currentmodule:: glue_genes.glue_single_cell.qt.enrichr

.. automodule:: glue_genes.glue_single_cell.qt.enrichr
